@@ -112,6 +112,7 @@ quick_enrich <- function(genes,
 ##' @param deg a data.frame contains at least two columns:"ENTREZID" and "change"
 ##' @param n how many terms will you perform for up and down genes respectively
 ##' @param color color for bar plot
+##' @inheritParams quick_enrich
 ##' @return a list with kegg and go bar plot according to up and down genes enrichment result.
 ##' @author Xiaojie Sun
 ##' @importFrom stringr str_to_lower
@@ -146,14 +147,14 @@ quick_enrich <- function(genes,
 ##' @seealso
 ##' \code{\link{quick_enrich}}
 
-double_enrich <- function(deg,n = 10,color = c("#2874C5", "#f87669")){
+double_enrich <- function(deg,n = 10,color = c("#2874C5", "#f87669"),species = "human"){
 
   if(!requireNamespace("labeling",quietly = TRUE)) {
     stop("Package \"labeling\" needed for this function to work. Please install it byby install.packages('labeling')",call. = FALSE)
   }
   deg$change = str_to_lower(deg$change)
-  up = quick_enrich(deg$ENTREZID[deg$change=="up"],"up.rdata",destdir = tempdir())
-  down = quick_enrich(deg$ENTREZID[deg$change=="down"],"down.rdata",destdir = tempdir())
+  up = quick_enrich(deg$ENTREZID[deg$change=="up"],"up.rdata",destdir = tempdir(),species = species)
+  down = quick_enrich(deg$ENTREZID[deg$change=="down"],"down.rdata",destdir = tempdir(),species = species)
   if(!is.null(up$kk) & !is.null(down$kk) &!is.null(up$go) &!is.null(up$go)){
     up$kk@result = mutate(up$kk@result,change = "up")
     down$kk@result = mutate(down$kk@result,change = "down")
